@@ -16,7 +16,7 @@
     [java.io File]
 
     ;; maven-resolver-api
-    [org.eclipse.aether RepositorySystem]
+    [org.eclipse.aether RepositorySystem RepositorySystemSession]
     [org.eclipse.aether.resolution ArtifactRequest ArtifactDescriptorRequest VersionRangeRequest]
 
     ;; maven-resolver-util
@@ -51,7 +51,7 @@
 
 (defmethod ext/dep-id :mvn
   [lib coord config]
-  (select-keys coord [:mvn/version :classifier]))
+  (select-keys coord [:mvn/version]))
 
 (defmethod ext/manifest-type :mvn
   [lib coord config]
@@ -74,7 +74,10 @@
   (let [local-repo (or local-repo maven/default-local-repo)
         system (maven/make-system)
         session (maven/make-session system local-repo)
-        artifact (maven/coord->artifact lib coord)
+        ;; if multiple classifiers, just use first to lookup dep
+        classifier (:classifier coord)
+        lookup-coord (cond-> coord (coll? classifier) (assoc :classifier (first classifier)))
+        artifact (maven/coord->artifact lib lookup-coord)
         req (ArtifactDescriptorRequest. artifact (mapv maven/remote-repo repos) nil)
         result (.readArtifactDescriptor system session req)]
     (into []
@@ -85,20 +88,29 @@
         (map #(update-in % [1] dissoc :scope :optional)))
       (.getDependencies result))))
 
-(defmethod ext/coord-paths :mvn
-  [lib coord _manifest {:keys [mvn/repos mvn/local-repo]}]
-  (let [local-repo (or local-repo maven/default-local-repo)
-        system (maven/make-system)
-        session (maven/make-session system local-repo)
-        artifact (maven/coord->artifact lib coord)
-        req (ArtifactRequest. artifact (mapv maven/remote-repo repos) nil)
+(defn- get-artifact
+  [lib coord ^RepositorySystem system ^RepositorySystemSession session mvn-repos]
+  (let [artifact (maven/coord->artifact lib coord)
+        req (ArtifactRequest. artifact mvn-repos nil)
         result (.resolveArtifact system session req)
         exceptions (.getExceptions result)]
     (cond
-      (.isResolved result) [(.. result getArtifact getFile getAbsolutePath)]
+      (.isResolved result) (.. result getArtifact getFile getAbsolutePath)
       (.isMissing result) (throw (ex-info (str "Unable to download: [" lib (pr-str (:mvn/version coord)) "]") {:lib lib :coord coord}))
       :else (throw (first (.getExceptions result))))))
 
+(defmethod ext/coord-paths :mvn
+  [lib coord _manifest {:keys [mvn/repos mvn/local-repo]}]
+  (let [local-repo (or local-repo maven/default-local-repo)
+        mvn-repos (mapv maven/remote-repo repos)
+        system (maven/make-system)
+        session (maven/make-session system local-repo)
+        classifier (:classifier coord)]
+    (if (coll? classifier)
+      (for [c classifier]
+        (get-artifact lib (assoc coord :classifier c) system session mvn-repos))
+      [(get-artifact lib coord system session mvn-repos)])))
+
 (comment
   (ext/lib-location 'org.clojure/clojure {:mvn/version "1.8.0"} {})
 
@@ -111,6 +123,18 @@
   ;; give a dep, download just that dep (not transitive - that's handled by the core algorithm)
   (ext/coord-paths 'org.clojure/clojure {:mvn/version "1.9.0-alpha17"} :mvn {:mvn/repos maven/standard-repos})
 
+  ;; get specific classifier
+  (ext/coord-paths 'org.jogamp.gluegen/gluegen-rt {:mvn/version "2.3.2" :classifier "natives-linux-amd64"}
+    :mvn {:mvn/repos maven/standard-repos})
+
+  ;; get multiple classifiers
+  (ext/coord-paths 'org.jogamp.gluegen/gluegen-rt {:mvn/version "2.3.2" :classifier ["" "natives-linux-amd64"]}
+    :mvn {:mvn/repos maven/standard-repos})
+
+  ;; deps for multiple classifier
+  (ext/coord-deps 'org.clojure/tools.reader {:mvn/version "1.3.0" :classifier ["" "aot"]}
+    :mvn {:mvn/repos maven/standard-repos})
+
   (parse-version {:mvn/version "1.1.0"})
 
   (ext/compare-versions {:mvn/version "1.1.0-alpha10"} {:mvn/version "1.1.0-beta1"})
